CircularArray

Struct CircularArray 

pub struct CircularArray<const N: usize, A, T> { /* private fields */ }
A circular array of N dimensions for elements of type T.

Supports any fixed size contiguous element buffer implementing AsRef<[T]> and AsMut<T>.

Implementations

Source

impl<const N: usize, A, T> CircularArray<N, A, T>
where A: AsRef<[T]>,

pub fn new(shape: [usize; N], array: A) -> CircularArray<N, A, T>

Create a new CircularArray from the given buffer.

Examples
let shape = [3, 3, 3];
let array = Vec::from_iter(0..shape.iter().product());

let circular_array = CircularArray::new(shape, array);
pub fn new_offset( shape: [usize; N], offset: [usize; N], array: A, ) -> CircularArray<N, A, T>

Create a new CircularArray from the given buffer and offset.

Examples
let shape = [3, 3, 3];
let array = Vec::from_iter(0..shape.iter().product());

// Offset by 1 on axis 0.
let circular_array = CircularArray::new_offset(shape, [1, 0, 0], array);
pub fn shape(&self) -> &[usize; N]

Get the shape array.

pub fn strides(&self) -> &Strides<N>

Get the array strides.

pub fn offset(&self) -> &[usize; N]

Get the array offset. This is not always incremented sequentually. Where a mutating operation inserts elements equal to the product of the array shape, the offset will be set to [0; N].

pub fn len(&self) -> usize

Get the number of elements in the array.

pub fn slice_len(&self, axis: usize) -> usize

Get the number of elements for a single slice of the buffer, for the given axis. Pushing n slices of elements onto an axis requires n * slice_len elements to be passed to the respective method.

pub fn next_offset(&self, axis: usize, n: isize) -> usize

Get the offset value after adding n slices to the given axis.

pub fn take(self) -> A

Drop the CircularArray, returning the inner buffer.

Source

impl<const N: usize, T> CircularArray<N, Vec<T>, T>

pub fn from_iter(shape: [usize; N], iter: impl Iterator<Item = T>) -> Self

Create a new CircularArrayVec from an iterator.

Examples
let shape = [3, 3, 3];
let circular_array = CircularArrayVec::from_iter(shape, 0..shape.iter().product());
pub fn from_iter_offset( shape: [usize; N], offset: [usize; N], iter: impl Iterator<Item = T>, ) -> Self

Create a new CircularArrayVec from an iterator with the given offset.

Examples
let shape = [3, 3, 3];
// Offset by 1 on axis 0.
let circular_array = CircularArrayVec::from_iter_offset(shape, [1, 0, 0], 0..shape.iter().product());
Source

impl<const N: usize, T> CircularArray<N, Box<[T]>, T>

pub fn from_iter(shape: [usize; N], iter: impl Iterator<Item = T>) -> Self

Create a new CircularArrayBox from an iterator.

Examples
let shape = [3, 3, 3];
let circular_array = CircularArrayBox::from_iter(shape, 0..shape.iter().product());
pub fn from_iter_offset( shape: [usize; N], iter: impl Iterator<Item = T>, offset: [usize; N], ) -> Self

Create a new CircularArrayBox from an iterator with the given offset.

Examples
let shape = [3, 3, 3];
// Offset by 1 on axis 0.
let circular_array = CircularArrayBox::from_iter_offset(shape, 0..shape.iter().product(), [1, 0, 0]);