Struct CircularArray

pub struct CircularArray<const N: usize, A, T> { /* private fields */ }
A circular array of D dimensions holding elements of type T.

Implementations

Source

impl<const N: usize, A, T> CircularArray<N, A, T>
where A: AsRef<[T]>,

pub fn new(shape: [usize; N], array: A) -> CircularArray<N, A, T>

pub fn new_offset( shape: [usize; N], array: A, offset: [usize; N], ) -> CircularArray<N, A, T>

pub fn shape(&self) -> &[usize; N]

Get the shape array.

pub fn offset(&self) -> &[usize; N]

Get the offset array.

pub fn slice_len(&self, axis: usize) -> usize

Get the number of elements for a single slice of the array, for the given axis. Pushing n slices of elements onto an axis requires n * slice_len elements to be passed to the respective method.

pub fn next_offset(&self, axis: usize, n: isize) -> usize

Get the offset value after adding n to the given axis.

Source

impl<const N: usize, T> CircularArray<N, Vec<T>, T>

pub fn from_iter(shape: [usize; N], iter: impl Iterator<Item = T>) -> Self

pub fn from_iter_offset( shape: [usize; N], iter: impl Iterator<Item = T>, offset: [usize; N], ) -> Self

Source

impl<const N: usize, T> CircularArray<N, Box<[T]>, T>

pub fn from_iter(shape: [usize; N], iter: impl Iterator<Item = T>) -> Self

pub fn from_iter_offset( shape: [usize; N], iter: impl Iterator<Item = T>, offset: [usize; N], ) -> Self