pub struct CircularArray<const N: usize, A, T> { /* private fields */ }Expand description
A circular array of D dimensions holding elements of type T.
Implementations
Sourceimpl<const N: usize, A, T> CircularArray<N, A, T>
impl<const N: usize, A, T> CircularArray<N, A, T>
pub fn new(shape: [usize; N], array: A) -> CircularArray<N, A, T>
pub fn new_offset( shape: [usize; N], array: A, offset: [usize; N], ) -> CircularArray<N, A, T>
Sourcepub fn slice_len(&self, axis: usize) -> usize
pub fn slice_len(&self, axis: usize) -> usize
Get the number of elements for a single slice of the array, for the given
axis. Pushing n slices of elements onto an axis requires n * slice_len
elements to be passed to the respective method.
Sourcepub fn next_offset(&self, axis: usize, n: isize) -> usize
pub fn next_offset(&self, axis: usize, n: isize) -> usize
Get the offset value after adding n to the given axis.
Sourceimpl<const N: usize, T> CircularArray<N, Vec<T>, T>
impl<const N: usize, T> CircularArray<N, Vec<T>, T>